# AJAX Extra
Provides additional commands to the Drupal core AJAX framework.

For use by developers who want to add effects to an AJAX callback.

For a full description of the module, visit the [project page](https://www.drupal.org/project/ajax_extra).

Submit bug reports and feature suggestions, or track changes in the
[issue queue](https://www.drupal.org/project/issues/ajax_extra).

## Commands

- **AnimatedScrollCommand**
Animated scrolling of a container to the top of a target child element.


## Installation

Install as you would normally install a contributed Drupal module. For further information, see [Installing Drupal Modules](https://www.drupal.org/docs/extending-drupal/installing-drupal-modules).


## Usage

Add AJAX Extra commands to AJAX callbacks.

```
  /**
   * Ajax callback.
   */
  public static function myAjax(array &$form, FormStateInterface $form_state) : AjaxResponse {
    $response = new AjaxResponse();

    // Scroll to latest reply.
    $container = '.thread-messages';
    $selector = '.thread-messages .reply:last-child';
    // AJAX Extra AnimatedScrollCommand command.
    $response->addCommand(new AnimatedScrollCommand($container, $selector));

    return $response;
  }
```

Add the AJAX Extra library for the command being used to the render array.

For example on a form render array:

```
$form['#attached']['library'][] = 'core/drupal.ajax';
$form['#attached']['library'][] = 'ajax_extra/ajax_extra.animated_scroll';
```

## Maintainers

- Robert Castelo - [robert-castelo](https://www.drupal.org/u/robert-castelo)