<?php

namespace Drupal\ajax_extra\Ajax;

use Drupal\Core\Ajax\CommandInterface;

/**
 * Provides an AJAX command for scrolling to the top of a target child element.
 *
 * This command is implemented in Drupal.AjaxCommands.prototype.animatedScroll.
 */
class AnimatedScrollCommand implements CommandInterface {

  /**
   * A CSS selector string for the container to be scrolled.
   *
   * @var string
   */
  protected $container;

  /**
   * A CSS selector string for the target element to be scrolled to.
   *
   * @var string
   */
  protected $target;

  /**
   * Speed of scroll animation.
   *
   * @var string
   */
  protected $speed;

  /**
   * Style of animation.
   *
   * @var string
   */
  protected $easing;

  /**
   * Constructs a \Drupal\ajax_extra\Ajax\AnimatedScrollCommand object.
   *
   * @param string $container
   *   A CSS selector string for the container to be scrolled.
   * @param string $target
   *   A CSS selector string for the target element to be scrolled to.
   * @param string $speed
   *   Speed of scroll animation. Default is slow. Optional.
   * @param string $easing
   *   Style of animation: 'swing' (default) or 'linear'. Optional.
   */
  public function __construct($container, $target, $speed = 'slow', $easing = 'swing') {
    $this->container = $container;
    $this->target = $target;
    $this->speed = $speed;
    $this->easing = $easing;
  }

  /**
   * Implements Drupal\Core\Ajax\CommandInterface:render().
   */
  public function render() {
    return [
      'command' => 'animatedScroll',
      'container' => $this->container,
      'target' => $this->target,
      'speed' => $this->speed,
    ];
  }

}
